package lt05_pkg;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;

import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 * This class encapsulates a JFrame child that is very simple; it contains a
 * single JPanel component of type CanvasPanel. The preferred size for this
 * window is 400x400. The behaviour when the window is closed is to terminate
 * the VM (if this window is the last window open of this app). <b>This class
 * also implements ModelListener and installs itself upon the passed model. When
 * the model changes, this view is notified and responds accordingly.</b>
 * 
 * @author mb
 * 
 */
public class BasicFrame extends JFrame implements ModelListener {
	private JPanel thePanel;

	/**
	 */
	public BasicFrame(PolkaDotDataModel myDataModel) {

		int width = 400;
		int height = width;
		this.setPreferredSize(new Dimension(width, height));

		this.setTitle("Labtest 05 Frame");

		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		this.setLayout(new BorderLayout());

		/*
		 * here we specify the components that should be added to this top-level
		 * container
		 */
		Container rootContainer = this.getContentPane();

		thePanel = new CanvasPanel(myDataModel);
		rootContainer.add(thePanel, BorderLayout.CENTER);

		/*
		 * the method pack() causes this JFrame to be sized to fit the preferred
		 * size and layouts of its subcomponents.
		 */
		this.pack();
		this.setVisible(true);

		// here we install this view as a listener on the model.
		// this makes sense because this view depends upon the model in order to
		// know how to draw itself.
		myDataModel.addListener(this);
		// myDataModel.addListener((ModelListener) thePanel);

	}

	/**
	 * The method alerts this view that the model upon which it depends has
	 * changed. As well, a statement is printed to the console
	 * "View detects that model has changed and signals it needs to be redrawn."
	 */
	@Override
	public void changed() {
		System.out
				.println("View detects that model has changed and signals it needs to be redrawn.");
		this.repaint();
	}

	@Override
	public void addMouseListener(MouseListener l) {
		thePanel.addMouseListener(l);
	}

	@Override
	public void addMouseMotionListener(MouseMotionListener l) {
		thePanel.addMouseMotionListener(l);
	}

}
